==> estateplat-common-1.2.4-20211028.053702-925-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxm.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请项目表
 */
@Table(name = "GX_WW_SQXM")
public class GxWwSqxm implements Serializable {
    private static final long serialVersionUID = 1234858668237889530L;
    @Id
    private String xmid;
    private String sqslbh;//申请受理编号
    private String bdcdjslbh;//不动产受理编号
    private Date sqsj;//申请时间
    private String sqrmc;//申请人名称
    private String sqrid;//申请人id
    private Date tssj;//推送时间
    private Date gxsj;//更新时间
    private String djzt;//登记状态
    private String byslyy;//不予受理原因
    private String sqlx;//申请类型
    private String dwdm;//单位代码
    private String cjr;//创建人
    private String sfcj; //是否创建项目0，1
    private String zsly;//证书来源
    private String sqly;//申请来源
    private String shzt;//审核状态（0或者空为未审核，1为审核通过，2未审核不通过）
    private String wszt;//0：未完税，1：已完税
    private String cjrsxfs;//创建人实现方式
    private String yybmbm;//预约部门编码
    private Date cjsj;
    private String bcxrmc;//被查询人名称
    private String bcxrzjh;//被查询人证件号
    private String bcxrsfzjzl;//被查询人省份证件种类
    private String cbr;//承包人
    private String fymc; //法院名称
    private String kzwjmc; //控制文件名称
    private String ythywbh;//一体化业务编号
    private String tsbj;//特殊标记
    private String sfhcdzzz;//是否合成电子证照（是，否）
    private String yhlyxt;//银行系统来源
    private String cjrjsmc;//创建人角色名称
    private String fybh;//税费发票号
    private String lzfs;//领证方式
    private String sqrzjh;//申请人证件号

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSqslbh() {
        return sqslbh;
    }

    public void setSqslbh(String sqslbh) {
        this.sqslbh = sqslbh;
    }

    public String getBdcdjslbh() {
        return bdcdjslbh;
    }

    public void setBdcdjslbh(String bdcdjslbh) {
        this.bdcdjslbh = bdcdjslbh;
    }

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrid() {
        return sqrid;
    }

    public void setSqrid(String sqrid) {
        this.sqrid = sqrid;
    }

    public Date getTssj() {
        return tssj;
    }

    public void setTssj(Date tssj) {
        this.tssj = tssj;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getByslyy() {
        return byslyy;
    }

    public void setByslyy(String byslyy) {
        this.byslyy = byslyy;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public String getSfcj() {
        return sfcj;
    }

    public void setSfcj(String sfcj) {
        this.sfcj = sfcj;
    }

    public String getZsly() {
        return zsly;
    }

    public void setZsly(String zsly) {
        this.zsly = zsly;
    }

    public String getSqly() {
        return sqly;
    }

    public void setSqly(String sqly) {
        this.sqly = sqly;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getWszt() {
        return wszt;
    }

    public void setWszt(String wszt) {
        this.wszt = wszt;
    }

    public String getCjrsxfs() {
        return cjrsxfs;
    }

    public void setCjrsxfs(String cjrsxfs) {
        this.cjrsxfs = cjrsxfs;
    }

    public String getYybmbm() {
        return yybmbm;
    }

    public void setYybmbm(String yybmbm) {
        this.yybmbm = yybmbm;
    }

    public String getBcxrmc() {
        return bcxrmc;
    }

    public void setBcxrmc(String bcxrmc) {
        this.bcxrmc = bcxrmc;
    }

    public String getBcxrzjh() {
        return bcxrzjh;
    }

    public void setBcxrzjh(String bcxrzjh) {
        this.bcxrzjh = bcxrzjh;
    }

    public String getBcxrsfzjzl() {
        return bcxrsfzjzl;
    }

    public void setBcxrsfzjzl(String bcxrsfzjzl) {
        this.bcxrsfzjzl = bcxrsfzjzl;
    }

    public String getCbr() {
        return cbr;
    }

    public void setCbr(String cbr) {
        this.cbr = cbr;
    }

    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    public String getKzwjmc() {
        return kzwjmc;
    }

    public void setKzwjmc(String kzwjmc) {
        this.kzwjmc = kzwjmc;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getYthywbh() {
        return ythywbh;
    }

    public void setYthywbh(String ythywbh) {
        this.ythywbh = ythywbh;
    }

    public String getTsbj() {
        return tsbj;
    }

    public void setTsbj(String tsbj) {
        this.tsbj = tsbj;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getYhlyxt() {
        return yhlyxt;
    }

    public void setYhlyxt(String yhlyxt) {
        this.yhlyxt = yhlyxt;
    }

    public String getCjrjsmc() {
        return cjrjsmc;
    }

    public void setCjrjsmc(String cjrjsmc) {
        this.cjrjsmc = cjrjsmc;
    }

    public String getFybh() {
        return fybh;
    }

    public void setFybh(String fybh) {
        this.fybh = fybh;
    }

    public String getLzfs() {
        return lzfs;
    }

    public void setLzfs(String lzfs) {
        this.lzfs = lzfs;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }
}

==> estateplat-common-1.2.4-20211029.033723-928-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxm.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请项目表
 */
@Table(name = "GX_WW_SQXM")
public class GxWwSqxm implements Serializable {
    private static final long serialVersionUID = 1234858668237889530L;
    @Id
    private String xmid;
    private String sqslbh;//申请受理编号
    private String bdcdjslbh;//不动产受理编号
    private Date sqsj;//申请时间
    private String sqrmc;//申请人名称
    private String sqrid;//申请人id
    private Date tssj;//推送时间
    private Date gxsj;//更新时间
    private String djzt;//登记状态
    private String byslyy;//不予受理原因
    private String sqlx;//申请类型
    private String dwdm;//单位代码
    private String cjr;//创建人
    private String sfcj; //是否创建项目0，1
    private String zsly;//证书来源
    private String sqly;//申请来源
    private String shzt;//审核状态（0或者空为未审核，1为审核通过，2未审核不通过）
    private String wszt;//0：未完税，1：已完税
    private String cjrsxfs;//创建人实现方式
    private String yybmbm;//预约部门编码
    private Date cjsj;
    private String bcxrmc;//被查询人名称
    private String bcxrzjh;//被查询人证件号
    private String bcxrsfzjzl;//被查询人省份证件种类
    private String cbr;//承包人
    private String fymc; //法院名称
    private String kzwjmc; //控制文件名称
    private String ythywbh;//一体化业务编号
    private String tsbj;//特殊标记
    private String sfhcdzzz;//是否合成电子证照（是，否）
    private String yhlyxt;//银行系统来源
    private String cjrjsmc;//创建人角色名称
    private String fybh;//税费发票号
    private String lzfs;//领证方式
    private String sqrzjh;//申请人证件号
    private String zdzf;//自动转发

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSqslbh() {
        return sqslbh;
    }

    public void setSqslbh(String sqslbh) {
        this.sqslbh = sqslbh;
    }

    public String getBdcdjslbh() {
        return bdcdjslbh;
    }

    public void setBdcdjslbh(String bdcdjslbh) {
        this.bdcdjslbh = bdcdjslbh;
    }

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrid() {
        return sqrid;
    }

    public void setSqrid(String sqrid) {
        this.sqrid = sqrid;
    }

    public Date getTssj() {
        return tssj;
    }

    public void setTssj(Date tssj) {
        this.tssj = tssj;
    }

    public Date getGxsj() {
        return gxsj;
    }

    public void setGxsj(Date gxsj) {
        this.gxsj = gxsj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getByslyy() {
        return byslyy;
    }

    public void setByslyy(String byslyy) {
        this.byslyy = byslyy;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public String getSfcj() {
        return sfcj;
    }

    public void setSfcj(String sfcj) {
        this.sfcj = sfcj;
    }

    public String getZsly() {
        return zsly;
    }

    public void setZsly(String zsly) {
        this.zsly = zsly;
    }

    public String getSqly() {
        return sqly;
    }

    public void setSqly(String sqly) {
        this.sqly = sqly;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getWszt() {
        return wszt;
    }

    public void setWszt(String wszt) {
        this.wszt = wszt;
    }

    public String getCjrsxfs() {
        return cjrsxfs;
    }

    public void setCjrsxfs(String cjrsxfs) {
        this.cjrsxfs = cjrsxfs;
    }

    public String getYybmbm() {
        return yybmbm;
    }

    public void setYybmbm(String yybmbm) {
        this.yybmbm = yybmbm;
    }

    public String getBcxrmc() {
        return bcxrmc;
    }

    public void setBcxrmc(String bcxrmc) {
        this.bcxrmc = bcxrmc;
    }

    public String getBcxrzjh() {
        return bcxrzjh;
    }

    public void setBcxrzjh(String bcxrzjh) {
        this.bcxrzjh = bcxrzjh;
    }

    public String getBcxrsfzjzl() {
        return bcxrsfzjzl;
    }

    public void setBcxrsfzjzl(String bcxrsfzjzl) {
        this.bcxrsfzjzl = bcxrsfzjzl;
    }

    public String getCbr() {
        return cbr;
    }

    public void setCbr(String cbr) {
        this.cbr = cbr;
    }

    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    public String getKzwjmc() {
        return kzwjmc;
    }

    public void setKzwjmc(String kzwjmc) {
        this.kzwjmc = kzwjmc;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getYthywbh() {
        return ythywbh;
    }

    public void setYthywbh(String ythywbh) {
        this.ythywbh = ythywbh;
    }

    public String getTsbj() {
        return tsbj;
    }

    public void setTsbj(String tsbj) {
        this.tsbj = tsbj;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getYhlyxt() {
        return yhlyxt;
    }

    public void setYhlyxt(String yhlyxt) {
        this.yhlyxt = yhlyxt;
    }

    public String getCjrjsmc() {
        return cjrjsmc;
    }

    public void setCjrjsmc(String cjrjsmc) {
        this.cjrjsmc = cjrjsmc;
    }

    public String getFybh() {
        return fybh;
    }

    public void setFybh(String fybh) {
        this.fybh = fybh;
    }

    public String getLzfs() {
        return lzfs;
    }

    public void setLzfs(String lzfs) {
        this.lzfs = lzfs;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }

    public String getZdzf() {
        return zdzf;
    }

    public void setZdzf(String zdzf) {
        this.zdzf = zdzf;
    }
}
